@@ -1,4 +1,4 @@
-from question_extractor import *
+from question_extractor.question_extractor import *
 
 
 model = load_model_()
